@@ -5,7 +5,7 @@ Set connect and read timeout for ZabbixAPI requests
 from pyzabbix import ZabbixAPI
 
 # The hostname at which the Zabbix web interface is available
-ZABBIX_SERVER = 'https://zabbix.example.com'
+ZABBIX_SERVER = "https://zabbix.example.com"
 
 # Timeout (float) in seconds
 # By default this timeout affects both the "connect" and "read", but
@@ -17,7 +17,7 @@ TIMEOUT = 3.5
 zapi = ZabbixAPI(ZABBIX_SERVER, timeout=TIMEOUT)
 
 # Login to the Zabbix API
-zapi.login('api_username', 'api_password')
+zapi.login("api_username", "api_password")
 
 # Or you can re-define it after
 zapi.timeout = TIMEOUT
